@@ -17,21 +17,21 @@ import mock
 from google.api_core.future import _helpers
 
 
-@mock.patch('threading.Thread', autospec=True)
+@mock.patch("threading.Thread", autospec=True)
 def test_start_deamon_thread(unused_thread):
     deamon_thread = _helpers.start_daemon_thread(target=mock.sentinel.target)
     assert deamon_thread.daemon is True
 
 
 def test_safe_invoke_callback():
-    callback = mock.Mock(spec=['__call__'], return_value=42)
-    result = _helpers.safe_invoke_callback(callback, 'a', b='c')
+    callback = mock.Mock(spec=["__call__"], return_value=42)
+    result = _helpers.safe_invoke_callback(callback, "a", b="c")
     assert result == 42
-    callback.assert_called_once_with('a', b='c')
+    callback.assert_called_once_with("a", b="c")
 
 
 def test_safe_invoke_callback_exception():
-    callback = mock.Mock(spec=['__call__'], side_effect=ValueError())
-    result = _helpers.safe_invoke_callback(callback, 'a', b='c')
+    callback = mock.Mock(spec=["__call__"], side_effect=ValueError())
+    result = _helpers.safe_invoke_callback(callback, "a", b="c")
     assert result is None
-    callback.assert_called_once_with('a', b='c')
+    callback.assert_called_once_with("a", b="c")
